==> fasc-openapi-java-sdk-5.2.3.0-sources.jar: com/fasc/open/api/v5_1/res/seal/GetListSealInfo.java <==
package com.fasc.open.api.v5_1.res.seal;

import com.fasc.open.api.bean.base.BaseBean;

import java.util.List;

/**
 * @author gongj
 * @date 2022/7/13
 */
public class GetListSealInfo extends BaseBean {
    private Long sealId;
    private String sealName;
    private String sealTag;
    private String categoryType;
    private String picFileUrl;
    private String sealStatus;
    private String createTime;
    private String certCAOrg;
    private String certEncryptType;
    private List<GetListSealUser> sealUsers;

    public Long getSealId() {
        return sealId;
    }

    public void setSealId(Long sealId) {
        this.sealId = sealId;
    }

    public String getSealName() {
        return sealName;
    }

    public void setSealName(String sealName) {
        this.sealName = sealName;
    }

    public String getCategoryType() {
        return categoryType;
    }

    public void setCategoryType(String categoryType) {
        this.categoryType = categoryType;
    }

    public String getPicFileUrl() {
        return picFileUrl;
    }

    public void setPicFileUrl(String picFileUrl) {
        this.picFileUrl = picFileUrl;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getCertCAOrg() {
        return certCAOrg;
    }

    public void setCertCAOrg(String certCAOrg) {
        this.certCAOrg = certCAOrg;
    }

    public String getCertEncryptType() {
        return certEncryptType;
    }

    public void setCertEncryptType(String certEncryptType) {
        this.certEncryptType = certEncryptType;
    }

    public List<GetListSealUser> getSealUsers() {
        return sealUsers;
    }

    public void setSealUsers(List<GetListSealUser> sealUsers) {
        this.sealUsers = sealUsers;
    }

    public String getSealTag() {
        return sealTag;
    }

    public void setSealTag(String sealTag) {
        this.sealTag = sealTag;
    }

    public String getSealStatus() {
        return sealStatus;
    }

    public void setSealStatus(String sealStatus) {
        this.sealStatus = sealStatus;
    }
}

==> fasc-openapi-java-sdk-5.2.6.2-sources.jar: com/fasc/open/api/v5_1/res/seal/GetListSealInfo.java <==
package com.fasc.open.api.v5_1.res.seal;

import com.fasc.open.api.bean.base.BaseBean;

import java.util.List;

/**
 * @author gongj
 * @date 2022/7/13
 */
public class GetListSealInfo extends BaseBean {
    private Long sealId;
    private String sealName;
    private String sealTag;
    private String categoryType;
    private String picFileUrl;
    private String sealStatus;
    private String createTime;
    private String certCAOrg;
    private String certEncryptType;
    private List<GetListSealUser> sealUsers;
    private List<FreeSignInfo> freeSignInfos;

    public Long getSealId() {
        return sealId;
    }

    public void setSealId(Long sealId) {
        this.sealId = sealId;
    }

    public String getSealName() {
        return sealName;
    }

    public void setSealName(String sealName) {
        this.sealName = sealName;
    }

    public String getCategoryType() {
        return categoryType;
    }

    public void setCategoryType(String categoryType) {
        this.categoryType = categoryType;
    }

    public String getPicFileUrl() {
        return picFileUrl;
    }

    public void setPicFileUrl(String picFileUrl) {
        this.picFileUrl = picFileUrl;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getCertCAOrg() {
        return certCAOrg;
    }

    public void setCertCAOrg(String certCAOrg) {
        this.certCAOrg = certCAOrg;
    }

    public String getCertEncryptType() {
        return certEncryptType;
    }

    public void setCertEncryptType(String certEncryptType) {
        this.certEncryptType = certEncryptType;
    }

    public List<GetListSealUser> getSealUsers() {
        return sealUsers;
    }

    public void setSealUsers(List<GetListSealUser> sealUsers) {
        this.sealUsers = sealUsers;
    }

    public String getSealTag() {
        return sealTag;
    }

    public void setSealTag(String sealTag) {
        this.sealTag = sealTag;
    }

    public String getSealStatus() {
        return sealStatus;
    }

    public void setSealStatus(String sealStatus) {
        this.sealStatus = sealStatus;
    }

    public List<FreeSignInfo> getFreeSignInfos() {
        return freeSignInfos;
    }

    public void setFreeSignInfos(List<FreeSignInfo> freeSignInfos) {
        this.freeSignInfos = freeSignInfos;
    }
}
